translate.storage.subtitles.SubRipFile

Package translate :: Package storage :: Module subtitles :: Class SubRipFile |
[hide private]
[frames] | no frames]

# Class SubRipFile

source code

specialized class for SubRipFile's only

Nested Classes | [hide private]
Inherited from `SubtitleFile`: `UnitClass`

Instance Methods | [hide private]
__init__(self, *args, **kwargs) construct an Subtitle file, optionally reading in from inputfile. | source code
Inherited from `SubtitleFile`: `__str__`, `parse` Inherited from `SubtitleFile` (private): `_parse`, `_parsefile` Inherited from `base.TranslationStore`: `__getstate__`, `__setstate__`, `add_unit_to_index`, `addsourceunit`, `addunit`, `findid`, `findunit`, `findunits`, `getids`, `getsourcelanguage`, `gettargetlanguage`, `getunits`, `isempty`, `makeindex`, `remove_unit_from_index`, `require_index`, `save`, `savefile`, `setsourcelanguage`, `settargetlanguage`, `translate`, `unit_iter` Inherited from `base.TranslationStore` (private): `_assignname` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `SubtitleFile`: `parsefile`, `parsestring`

Class Variables | [hide private]
| Name = `_("SubRip subtitles file")` The human usable name of this store type
| Extensions = `['srt']` A list of file extentions associated with this store type
Inherited from `base.TranslationStore`: `Mimetypes`, `suggestions_in_format` Inherited from `base.TranslationStore` (private): `_binary`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, *args, **kwargs) (Constructor) | source code
construct an Subtitle file, optionally reading in from inputfile. Overrides: object.__init__ (inherited documentation)